@@ -49,14 +49,16 @@ def pytest_configure(config):
         key
         for key in dir(gb.semiring)
         if isinstance(
-            getattr(gb.semiring, key), (gb.operator.Semiring, gb.operator.ParameterizedSemiring)
+            getattr(gb.semiring, key),
+            (gb.core.operator.Semiring, gb.core.operator.ParameterizedSemiring),
         )
     )
     orig_binaryops.update(
         key
         for key in dir(gb.binary)
         if isinstance(
-            getattr(gb.binary, key), (gb.operator.BinaryOp, gb.operator.ParameterizedBinaryOp)
+            getattr(gb.binary, key),
+            (gb.core.operator.BinaryOp, gb.core.operator.ParameterizedBinaryOp),
         )
     )
     for mod in [gb.unary, gb.binary, gb.monoid, gb.semiring, gb.op]:
